GEOWATCH On Windows
~~~~~~~~~~~~~~~~~~~

Windows usage is far less tested than Linux. If possible use Linux, but we will
try to support windows.  This document outlines high level steps to get
geowatch running on windows.  We will use miniconda3 for Python. Other options
will works.



Steps I used on windows 10:

Download `Miniconda3 Windows 64-bit installer <https://docs.conda.io/en/latest/miniconda.html>`_ (with Python 3.10 as the default).

Run the installer (using default settings).

From the start menu, run the Anaconda Prompt (miniconda).


https://gitlab.kitware.com/computer-vision/geowatch.git
